==> logtalk-3.63.0.tar.bz2: logtalk-3.63.0/library/statistics/NOTES.md <==

________________________________________________________________________

This file is part of Logtalk <https://logtalk.org/>  
Copyright 1998-2023 Paulo Moura <pmoura@logtalk.org>  
SPDX-License-Identifier: Apache-2.0

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
________________________________________________________________________


`statistics`
============

The entities in this group define some useful predicates for descriptive
statistics. Data is represented as a list of numbers (integers or floats).
Use the object `sample` of your data represents a sample. Use the object 
`population` if your data represents a population.


API documentation
-----------------

Open the [../../docs/library_index.html#statistics](../../docs/library_index.html#statistics)
link in a web browser.


Loading
-------

To load all entities in this library, load the `loader.lgt` file:

	| ?- logtalk_load(statistics(loader)).


Testing
-------

To test this library predicates, load the `tester.lgt` file:

	| ?- logtalk_load(statistics(tester)).

==> logtalk-3.89.1.tar.bz2: logtalk-3.89.1/library/statistics/NOTES.md <==

________________________________________________________________________

This file is part of Logtalk <https://logtalk.org/>  
SPDX-FileCopyrightText: 1998-2025 Paulo Moura <pmoura@logtalk.org>  
SPDX-License-Identifier: Apache-2.0

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
________________________________________________________________________


`statistics`
============

The entities in this library define some useful predicates for descriptive
statistics. Data is represented as a list of numbers (integers or floats).
Use the object `sample` of your data represents a sample. Use the object 
`population` if your data represents a population.


API documentation
-----------------

Open the [../../docs/library_index.html#statistics](../../docs/library_index.html#statistics)
link in a web browser.


Loading
-------

To load all entities in this library, load the `loader.lgt` file:

	| ?- logtalk_load(statistics(loader)).


Testing
-------

To test this library predicates, load the `tester.lgt` file:

	| ?- logtalk_load(statistics(tester)).
